@@ -20,7 +20,7 @@ def run(command, s, m, h):
     """\b
        Run commands repetitively at a given interval starting from
        current moment.
-
+        \b
        Example: lash sched run "help" 0 0 5 """
     try:
         if h <= 0 and m <= 0 and s <= 0:
@@ -28,9 +28,13 @@ def run(command, s, m, h):
     except Exception as e:
         print(e)
     t = h * 3600 + m * 60 + s  # Converting to seconds
-    sc.every(t).seconds.do(system, command=command)
     while True:
-        sc.run_pending()
+        for i in range(0, t):
+            print(f'Time remaining: {(t - i) // 60 // 60}h {(t - i) // 60}m {t - i}s ', end="\r")
+            sleep(1)
+        print(f'Time remaining: 0h 0m 0s ', end="\r")
+        system(command=command)
+        print()
 
 
 @sched.command()
@@ -41,7 +45,9 @@ def run(command, s, m, h):
 def wait(command, h, m, s):
     """\b
         Wait x time, run a task once and exit
-        Example: lash sched wait "help" 0 0 10  """
+        \b
+        Example: lash sched wait "help" 0 0 10
+    """
     # assert h <= 0 and m <= 0 and s <= 0, 'Error: Time delay is not defined'
     t = h * 3600 + m * 60 + s  # Converting to seconds
     for i in range(0, t):
@@ -69,5 +75,5 @@ def exec(time, command):
             system(command=command)
             return
         else:
-            print(f'Waiting {time} -> {datetime.now().hour}:{datetime.now().minute}:{datetime.now().second}', end='\r')
+            print(f' Waiting {time} -> {datetime.now().hour}:{datetime.now().minute}:{datetime.now().second}', end='\r')
 
